@@ -40,7 +40,7 @@ class TQWidget;
 
 // Plugin class starts here
 class MyPermPlugin: public Plugin {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         const TQString getName() const;
